==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/HRFKRayleighFixedEll.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-01-28
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKRAYLEIGHFIXEDELL_H
#define HRFKRAYLEIGHFIXEDELL_H

#include "HRFKRayleigh.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKRayleighFixedEll : public HRFKRayleigh
  {
  public:
    HRFKRayleighFixedEll(FKCache * gridCache)
      : HRFKRayleigh(gridCache) {_ellipticity=0.0;}

  virtual bool setFixedEllipticity(double frequency);
  void setEllipticity(double ell);

  virtual void setGrid(FKGridSearch * g, double step, double size);
  virtual bool initGrid(int n);
  virtual void initGrid(const Point& k, int index);

  virtual double value(const Point& k, int index) const;
  virtual double value(const Point& k) const;

  virtual double ellipticity(const Point&) {return _ellipticity;}

  bool loadFixedEllipticityCurve(const QString& fileName);
private:
  double _ellipticity;

  Curve<Point2D> _fixedEllipticities;
  };

} // namespace ArrayCore

#endif // HRFKRAYLEIGHFIXEDELL_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/ArrayCore/src/HRFKRayleighFixedEll.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-01-28
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKRAYLEIGHFIXEDELL_H
#define HRFKRAYLEIGHFIXEDELL_H

#include "HRFKRayleigh.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKRayleighFixedEll : public HRFKRayleigh
  {
  public:
    HRFKRayleighFixedEll(FKCache * cache)
      : HRFKRayleigh(cache) {}

    bool setFixedEllipticity(double frequency);

    double value(const Vector<int>& index) const;
    double value(Vector<double>& k) const;

    double ellipticity(const Vector<double>&) {return _currentFixedEllipticity;}

    bool loadFixedEllipticityCurve(const QString& fileName);
  private:
    double _currentFixedEllipticity;
    Curve<Point2D> _fixedEllipticities;
  };

} // namespace ArrayCore

#endif // HRFKRAYLEIGHFIXEDELL_H
